==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Wszystkie czcionki</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktywny</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chiński</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospaced</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Uszkodzony plik</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Zainstalowano tę samą wersję</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Czcionka systemowa</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Czcionki</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Zainstalowano czcionkę %1</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Zainstalowano %1 czcionek</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Czy na pewno chcesz usunąć tę czcionkę?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ta czcionka nie będzie dostępna dla aplikacji</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Te czcionki nie będą dostępne dla aplikacji</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Nie można usunąć innych czcionek systemowych %1</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Nie można usunąć używanej czcionki „%1”</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Nie można usunąć innych czcionek systemowych %1 i używanej czcionki „%2”</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Czy na pewno chcesz usunąć %1 czcionka(ek)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Usuwam czcionki, proszę czekać...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Weryfikacja czcionki</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Brak czcionek do zainstalowania</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Nie pozwól, aby twoje sny były snami</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Podstawowa informacja</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Pełna nazwa</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nazwa PS</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Znak towarowy</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Zarządzanie czcionkami</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Menedżer czcionek pomaga użytkownikom instalować czcionki i zarządzać nimi.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Ładowanie czcionek, proszę czekać...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Czcionka wyeksportowana na pulpit</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 czcionek wyeksportowanych na pulpit</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nie udało się wyeksportować 1 czcionki. Za mało miejsca na dysku.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nie udało się wyeksportować %1 czcionek. Za mało miejsca na dysku.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Dodaj czcionkę</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubiony</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>dezaktywowany</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Czcionki zostały dezaktywowane</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 jest używana, więc nie możesz jej wyłączyć</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Nie można wyłączyć czcionek systemowych ani używanych czcionek</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Nie można wyłączyć czcionek systemowych</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Niektórych czcionek nie można wyłączyć</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Zainstaluj czcionkę</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Weryfikacja...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Uszkodzony plik</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Zainstalowano</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nie zainstalowany</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Zainstaluj czcionkę</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Brak czcionek</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Strona w górę</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Strona w dół</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Dodaj czcionkę</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubiony</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informacje o czcionce</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Wprowadź tekst podglądu</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Uszkodzony plik</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Wszystkie</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systemowe</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownika</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktywne</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chińskie</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospaced</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 jest rodziną czcionek, jeśli zamierzasz kontynuować, wszystkie czcionki w niej zostaną usunięte</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 jest rodziną czcionek, jeśli zamierzasz kontynuować, wszystkie czcionki w niej zostaną włączone</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 jest rodziną czcionek, jeśli zamierzasz kontynuować, wszystkie czcionki w niej zostaną wyłączone</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Wyłącz</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Zastosuj do wszystkich zaznaczonych rodzin czcionek</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Uszkodzony plik</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Zainstalowana ta sama wersja</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Czcionka systemowa</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Zainstalowano czcionkę %1</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Zainstalowano %1 czcionek</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Nie udało się zainstalować %1 czcionki. Niewystarczająca ilość miejsca na dysku.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Nie udało się zainstalować %1 czcionek. Niewystarczająca ilość miejsca na dysku.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ta czcionka nie będzie dostępna dla aplikacji</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Te czcionki nie będą dostępne dla aplikacji</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Nie można usunąć innych czcionek systemowych %1</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Czcionka &quot;%1&quot; jest w użyciu i nie może zostać usunięta</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>%1 czcionek systemowych i czcionka &quot;%2&quot; w użyciu nie może zostać usunięta</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Czy na pewno chcesz usunąć %1 czcionki?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Usuwam czcionki, proszę czekać...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Weryfikacja czcionki</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Brak czcionek do zainstalowania</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Wyjście</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Kontynuuj</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informacje podstawowe</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznana</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Pełna nazwa</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nazwa PS</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Znak towarowy</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Zarządzanie czcionkami</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Zarządzanie czcionkami pomaga użytkownikom instalować czcionki i zarządzać nimi.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Wczytywanie czcionek, proszę czekać...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Wyeksportowano czcionkę na pulpit</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>Wyeksportowano %1 czcionek na pulpit</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nie udało się wyeksportować 1 czcionki. Brak miejsca na dysku.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nie udało się wyeksportować %1 czcionek. Brak miejsca na dysku.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Dodaj czcionkę</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w Menedżerze plików</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>dezaktywowany</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Czcionki zostały dezaktywowane</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 jest w użyciu, więc nie możesz jej wyłączyć</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Nie można wyłączyć czcionek systemowych, ani tych w użyciu</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Nie można wyłączyć czcionek systemowych</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Zainstaluj czcionkę</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Weryfikowanie...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Nieznana</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Uszkodzony plik</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Zainstalowano</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nie zainstalowany</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Zainstaluj czcionkę</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Brak czcionek</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Strona w górę</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Strona w dół</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Dodaj czcionkę</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informacje o czcionce</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Wprowadź tekst do podglądu</translation>
    </message>
</context>
</TS>
